/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.model;

import java.util.*;

import edu.stanford.smi.protege.util.*;
/**
 * Base class for implementions of FacetConstraint.  Implementations are provided for the is/are valid methods that just
 * get the "invalid text" descriptions of the problems and test it.  If there is "invalid text" then the values are
 * not valid.
 *
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public abstract class AbstractFacetConstraint implements FacetConstraint {

    public boolean areValidValues(Frame frame, Slot slot, Collection slotValues, Collection facetValues) {
        return getInvalidValuesText(frame, slot, slotValues, facetValues) == null;
    }

    public boolean isValidValue(Frame frame, Slot slot, Object o, Collection facetValues) {
        return getInvalidValueText(frame, slot, o, facetValues) == null;
    }

    public static boolean equals(Object o1, Object o2) {
        return SystemUtilities.equals(o1, o2);
    }

    public String toString() {
        return StringUtilities.getClassName(this);
    }
}
