/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.model;

import java.util.*;

import edu.stanford.smi.protege.util.*;

/**
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */

public class BrowserSlotPattern {
    private List elements;

    public BrowserSlotPattern(Slot slot) {
        this.elements = new ArrayList();
        this.elements.add(slot);
    }

    public BrowserSlotPattern(List elements) {
        this.elements = new ArrayList(elements);
    }

    public Slot getFirstSlot() {
        Slot slot = null;
        Iterator i = elements.iterator();
        while (i.hasNext()) {
            Object o = i.next();
            if (o instanceof Slot) {
                slot = (Slot) o;
                break;
            }
        }
        return slot;
    }

    // just hack this for now to save the first slot
    public String getSerialization() {
        Object previous = null;
        StringBuffer buffer = new StringBuffer();
        Iterator i = elements.iterator();
        while (i.hasNext()) {
            Object o = i.next();
            if (o instanceof String) {
                buffer.append("{" + toSafeText((String) o) + "}");
            }
            if (o instanceof Slot) {
                if (previous instanceof Slot) {
                    buffer.append("{}");
                }
                Slot slot = (Slot) o;
                buffer.append(toSafeText(slot.getName()));
            }
            previous = o;
        }
        return buffer.toString();
    }

    private static String toSafeText(String s) {
        return FileUtilities.urlEncode(s);
    }

    private static String fromSafeText(String s) {
        return FileUtilities.urlDecode(s);
    }

    public static BrowserSlotPattern createFromSerialization(KnowledgeBase kb, String s) {
        boolean inText = false;
        List elements = new ArrayList();
        StringTokenizer tokenizer = new StringTokenizer(s, "{}", true);
        while (tokenizer.hasMoreTokens()) {
            String token = tokenizer.nextToken();
            if (token.equals("{")) {
                inText = true;
            } else if (token.equals("}")) {
                inText = false;
            } else if (inText) {
                String text = fromSafeText(token);
                elements.add(text);
            } else {
                String name = fromSafeText(token);
                Slot slot = kb.getSlot(name);
                if (slot != null) {
                    elements.add(slot);
                }
            }

        }
        return (elements.isEmpty()) ? null : new BrowserSlotPattern(elements);
    }

    public boolean contains(Slot slot) {
        return elements.contains(slot);
    }

    public List getElements() {
        return new ArrayList(elements);
    }

    public boolean equals(Object o) {
        boolean equals = false;
        if (o instanceof BrowserSlotPattern) {
            BrowserSlotPattern rhs = (BrowserSlotPattern) o;
            equals = CollectionUtilities.equalsList(elements, rhs.elements);
        }
        return equals;
    }

    public int hashCode() {
        return elements.get(0).hashCode();
    }

    public List getSlots() {
        List slots = new ArrayList();
        Iterator i = elements.iterator();
        while (i.hasNext()) {
            Object o = i.next();
            if (o instanceof Slot) {
                slots.add(o);
            }
        }
        return slots;
    }

    public String getBrowserText(Instance instance) {
        StringBuffer buffer = new StringBuffer();
        Iterator i = elements.iterator();
        while (i.hasNext()) {
            Object o = i.next();
            if (o instanceof Slot) {
                buffer.append(getText((Slot) o, instance));
            } else {
                buffer.append(o);
            }
        }
        return (buffer.length() == 0) ? null : buffer.toString();
    }

    private String getText(Slot slot, Instance instance) {
        String text;
        Object o = instance.getOwnSlotValue(slot);
        if (o == null) {
            text = "";
        } else if (o instanceof Frame) {
            if (o.equals(instance)) {
                text = "<recursive call>";
            } else {
                text = ((Frame) o).getBrowserText();
            }
        } else {
            text = o.toString();
        }
        return text;
    }

    public String toString() {
        return "BrowserSlotPattern(" + getSerialization() + ")";
    }
}
