/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.model;

import java.util.*;

import edu.stanford.smi.protege.event.*;

/**
 * An instance of a class.  The class is refered to as the direct type.
 * An instance can only have one direct type.  Note that, in Protege, all Frames are Instances so we could have
 * actually combined these two interfaces.  We choose not to.
 *
 * Note that classes and slots are also instances and implement this interface.
 * "Simple Instances" are instances which are not classes, slots, or facets. They
 * have their own interface SimpleInstance.
 *
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public interface Instance extends Frame {

    void addInstanceListener(InstanceListener listener);

    /** 
     * return the "first" direct type 
     */
    Cls getDirectType();

    Collection getDirectTypes();

    Collection getReachableSimpleInstances();

    boolean hasDirectType(Cls cls);

    boolean hasType(Cls cls);

    void removeInstanceListener(InstanceListener listener);

    Instance setDirectType(Cls cls);

    void addDirectType(Cls cls);
    void removeDirectType(Cls cls);
}
