/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.model.framestore;

import java.lang.reflect.*;
import java.util.*;

import edu.stanford.smi.protege.util.*;

class MethodCall {
    private Method _method;
    private Object[] _args;
    private int _hashCode;

    private static final Object[] NULL_ARGS = new Object[0];

    public MethodCall() {
    }

    public MethodCall(Method m, Object[] args) {
        Object[] safeArgs = null;
        if (args != null) {
            safeArgs = new Object[args.length];
            for (int i = 0; i < args.length; ++i) {
                Object o = args[i];
                if (o instanceof Collection) {
                    o = new ArrayList((Collection) o);
                    edu.stanford.smi.protege.util.Log.trace("allocating collection", this, "MethodCall", m, args);
                }
                // edu.stanford.smi.protege.util.Log.trace("saving args", this, "MethodCall", m);
                safeArgs[i] = o;
            }
        }
        set(m, safeArgs);
    }

    public void set(Method m, Object[] args) {
        _method = m;
        _args = (args == null) ? NULL_ARGS : args;
        _hashCode = HashUtils.getHash(m, _args);
    }

    public int hashCode() {
        return _hashCode;
    }

    public boolean equals(Object o) {
        MethodCall rhs = (MethodCall) o;
        boolean equals = _method.equals(rhs._method);
        equals &= _args.length == rhs._args.length;
        for (int i = 0; equals && i < _args.length; ++i) {
            equals = _args[i] == rhs._args[i];
        }
        return equals;
    }

    public String toString() {
        return "MethodCall";
    }
}