/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.model.framestore;

import edu.stanford.smi.protege.model.*;

public class ReadOnlyFrameStoreHandler_Test extends FrameStore_Test {
    private FrameStore _modifiableFrameStore;

    protected FrameStore createFrameStore(DefaultKnowledgeBase kb) {
        _modifiableFrameStore = new InMemoryFrameStore(kb);
        FrameStore fs = AbstractFrameStoreInvocationHandler.newInstance(ReadOnlyFrameStoreHandler.class);
        fs.setDelegate(_modifiableFrameStore);
        return fs;
    }

    public void tearDown() {
        super.tearDown();
        _modifiableFrameStore = null;
    }

    protected FrameStore getModifiableFrameStore(DefaultKnowledgeBase kb) {
        return _modifiableFrameStore;
    }

    public void testCreateCls() {
        boolean passed = false;
        try {
            getTestFrameStore().createCls(null, null, null, null, true);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testCreateSlot() {
        boolean passed = false;
        try {
            getTestFrameStore().createSlot(null, null, null, null, true);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testCreateSimpleInstance() {
        boolean passed = false;
        try {
            getTestFrameStore().createSimpleInstance(null, null, null, true);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }
    public void testCreateFacet() {
        boolean passed = false;
        try {
            getTestFrameStore().createFacet(null, null, null, true);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }
    public void testDeleteCls() {
        boolean passed = false;
        try {
            getTestFrameStore().deleteCls(null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }
    public void testDeleteSlot() {
        boolean passed = false;
        try {
            getTestFrameStore().deleteSlot(null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }
    public void testDeleteFacet() {
        boolean passed = false;
        try {
            getTestFrameStore().deleteFacet(null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }
    public void testDeleteSimpleInstance() {
        boolean passed = false;
        try {
            getTestFrameStore().deleteSimpleInstance(null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }
    public void testAddDirectTemplateSlot() {
        boolean passed = false;
        try {
            getTestFrameStore().addDirectTemplateSlot(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }
    public void testSetOwnSlotValues() {
        boolean passed = false;
        try {
            getTestFrameStore().setDirectOwnSlotValues(null, null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testSetFrameName() {
        boolean passed = false;
        try {
            getTestFrameStore().setFrameName(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testSetDirectOwnSlotValues() {
        boolean passed = false;
        try {
            getTestFrameStore().setDirectOwnSlotValues(null, null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testRemoveDirectTemplateSlot() {
        boolean passed = false;
        try {
            getTestFrameStore().removeDirectTemplateSlot(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testMoveDirectTemplateSlot() {
        boolean passed = false;
        try {
            getTestFrameStore().moveDirectTemplateSlot(null, null, 0);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testSetDirectTemplateSlotValues() {
        boolean passed = false;
        try {
            getTestFrameStore().setDirectTemplateSlotValues(null, null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testSetDirectTemplateFacetValues() {
        boolean passed = false;
        try {
            getTestFrameStore().setDirectTemplateFacetValues(null, null, null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testAddDirectSuperclass() {
        boolean passed = false;
        try {
            getTestFrameStore().addDirectSuperclass(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testRemoveDirectSuperclass() {
        boolean passed = false;
        try {
            getTestFrameStore().removeDirectSuperclass(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testMoveDirectSubclass() {
        boolean passed = false;
        try {
            getTestFrameStore().moveDirectSubclass(null, null, 0);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }
    public void testAddDirectSuperslot() {
        boolean passed = false;
        try {
            getTestFrameStore().addDirectSuperslot(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testRemoveDirectSuperslot() {
        boolean passed = false;
        try {
            getTestFrameStore().removeDirectSuperslot(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testAddDirectType() {
        boolean passed = false;
        try {
            getTestFrameStore().addDirectType(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testRemoveDirectType() {
        boolean passed = false;
        try {
            getTestFrameStore().removeDirectType(null, null);
        } catch (ModificationException e) {
            passed = true;
        }
        assertTrue(passed);
    }

    public void testSetInverseSlotValues() {
        // do nothing
    }
}
