/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.model.framestore.undo;

import java.util.*;

import edu.stanford.smi.protege.model.framestore.*;
import edu.stanford.smi.protege.util.*;

/**
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class MacroCommand implements Command {
    private List _commands = new ArrayList();
    private String _description;
    private FrameStore _delegate;

    public MacroCommand(String s, FrameStore fs) {
        _description = s;
        _delegate = fs;
    }

    public void add(Command command) {
        _commands.add(command);
    }

    public Object doIt() {
        throw new IllegalStateException();
    }

    public void undoIt() {
        ListIterator i = _commands.listIterator(_commands.size());
        while (i.hasPrevious()) {
            Command command = (Command) i.previous();
            // Log.trace("macro undoing: " + command.getDescription(), this, "undoIt");
            command.undoIt();
        }
    }

    public void redoIt() {
        _delegate.beginTransaction(_description);
        ListIterator i = _commands.listIterator();
        while (i.hasNext()) {
            Command command = (Command) i.next();
            // Log.trace("macro redoing: " + command.getDescription(), this, "redoIt");
            command.redoIt();
        }
        _delegate.commitTransaction();
    }

    public String getDescription() {
        return _description;
    }

    public String toString() {
        return StringUtilities.getClassName(this);
    }

}
